# encoding: utf-8
import os

config_dir = '.ssh4p'
config_home = os.path.join(os.path.expanduser('~'), config_dir)
host_map_file = 'host_map.json'
host_map_path = os.path.join(config_home, host_map_file)



# encoding: UTF-8
import json

from ssh4plib.host_storage import Host, HostStorage


class Manager(object):

    @staticmethod
    def list():
        host_list = HostStorage.all().values()
        Manager.__print_header_line__()
        for host in host_list:
            Manager.__print_line__(host)

    @staticmethod
    def __print_header_line__():
        Manager.__print_line__(Host(name="NAME", host="HOST", port="PORT", user="USER", password="PASSWORD", proxy="PROXY"))

    @staticmethod
    def __print_line__(host: Host):
        size = 20
        print(str(host.name).ljust(size) + str(host.host).ljust(size) + str(host.port).ljust(size) + str(host.user).ljust(
            size) + str(host.password).ljust(size) + str(host.proxy).ljust(size))



from distutils.core import setup
import os
from ssh4plib import version

long_description = """a shell ssh manager tools for python"""

setup(
    name="ssh4p",
    version=version.VERSION,
    author="xzcoder",
    author_email="zhushuai_it@163.com",
    description=long_description,
    long_description=long_description,
    platforms=['linux', 'macos'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: BSD License",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.4",
        "Programming Language :: Python :: 2.5",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Clustering",
        "Topic :: System :: Networking",
        "Topic :: System :: Systems Administration",
    ],
    packages=['ssh4plib'],
    scripts=[os.path.join("bin", p) for p in ["zssh", "zscp", "zssh-manager"]],
    install_requires=["pexpect"]
)



# encoding: UTF-8
import json

from typing import List
from ssh4plib.common import host_map_path


class Host:

    def __init__(self, **opts):
        self.name = opts.get('name', None)
        self.host = opts.get('host', None)
        self.port = opts.get('port', None)
        self.user = opts.get('user', None)
        self.password = opts.get('password', None)
        self.proxy = opts.get('proxy', None)

    # def __init__(self, dict_data: dict):
    #     self.name = dict_data.get('name', None)
    #     self.host = dict_data.get('host', None)
    #     self.port = dict_data.get('port', None)
    #     self.user = dict_data.get('user', None)
    #     self.password = dict_data.get('password', None)
    #     self.proxy = dict_data.get('proxy', None)

    @staticmethod
    def parse_dict(dict_data: dict):
        pass

    def to_dict(self):
        return self.__dict__

    def __str__(self):
        return str(self.to_dict())


class HostStorage(object):

    @staticmethod
    def all() -> dict:
        with open(host_map_path) as file:
            host_map_json = json.load(file)

        host_map = dict()
        for key in host_map_json:
            host = Host(**host_map_json[key])
            host.name = key
            host_map[key] = host
        return host_map

    @staticmethod
    def get(name: str) -> Host:
        return HostStorage.all().get(name, None)

    @staticmethod
    def saveBatch(host_list: List[Host]):
        pass


if __name__ == '__main__':
    print(HostStorage.all())
